/*
 * SPDX-FileCopyrightText: Copyright (c) 2024 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
 * SPDX-License-Identifier: LicenseRef-NvidiaProprietary
 *
 * NVIDIA CORPORATION, its affiliates and licensors retain all intellectual
 * property and proprietary rights in and to this material, related
 * documentation and any modifications thereto. Any use, reproduction,
 * disclosure or distribution of this material and related documentation
 * without an express license agreement from NVIDIA CORPORATION or
 * its affiliates is strictly prohibited.
 */
#ifndef SRC_CONFIGURATOR_CABLE_DB_CSV_RECORD_H_
#define SRC_CONFIGURATOR_CABLE_DB_CSV_RECORD_H_

#include <string>
#include <ibis/ibis.h>
#include <infiniband/ibdiag/ibdiag_types.h>
#include "internal_packets_layouts.h"


//
// Section ROW_MODULE_INFO
//  - pddr_module_info
//
class ModuleInfoRecord {
    public:
        std::string                 m_id;
        u_int8_t                    m_multi_plane;
        u_int8_t                    m_technology;
        std::string                 m_side;
        pddr_module_info            m_data;

    public:
        ModuleInfoRecord() :  m_multi_plane(0), m_technology(0), m_data({}) {}

        static int Init(std::vector < ParseFieldInfo <class ModuleInfoRecord> > &parse_section_info);
};

//
// Section ROW_LATCHED_FLAG_INFO
//  - module_latched_flag_info
//
class LatchedFlagInfoRecord {
    public:
        std::string                 m_id;
        u_int8_t                    m_multi_plane;
        u_int8_t                    m_technology;
        std::string                 m_side;
        module_latched_flag_info    m_data;

    public:
        LatchedFlagInfoRecord() : m_multi_plane(0), m_technology(0), m_data({}) {}

        static int Init(std::vector < ParseFieldInfo <class LatchedFlagInfoRecord> > &parse_section_info);
};

#endif // SRC_CONFIGURATOR_CABLE_DB_CSV_RECORD_H_
