/*
 * Copyright (c) 2004-2020 Mellanox Technologies LTD. All rights reserved
 * Copyright (c) 2023-2025 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
 * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 */


#include "ibis.h"
#include "key_mngr.h"

KeyManager::KeyManager():
    lid_2_key_vec_vec((int)IBIS_NUM_OF_KEY_TYPES, vector < IBISKey > (IBIS_IB_MAX_LID + 1)),
    default_keys(IBIS_NUM_OF_KEY_TYPES, IBIS_IB_DEFAULT_KEY)
{
}

const char* KeyManager::GetTypeName(IBISKeyType type)
{
    switch (type) {
        case IBIS_AM_KEY: return "AM Key";
        case IBIS_VS_KEY: return "VS Key";
        case IBIS_CC_KEY: return "CC Key";
        case IBIS_CLASS_C_KEY: return "M2N Key";
        case IBIS_PM_KEY: return "PM Key";
        default : return "";
    }
}

u_int64_t KeyManager::GetKey(u_int16_t lid, IBISKeyType key_type) const
{
    IBIS_ENTER;

    if (KeyManager::IsVlaidKeyType(key_type) && this->lid_2_key_vec_vec[key_type][lid].is_set)
        IBIS_RETURN(this->lid_2_key_vec_vec[key_type][lid].key);

    IBIS_RETURN(this->GetDefaultKey(key_type));
}

void KeyManager::SetKey(u_int16_t lid, IBISKeyType key_type, u_int64_t key)
{
    IBIS_ENTER;

    if (KeyManager::IsVlaidKeyType(key_type)) {
        this->lid_2_key_vec_vec[key_type][lid].key = key;
        this->lid_2_key_vec_vec[key_type][lid].is_set = true;
    }

    IBIS_RETURN_VOID;
}

void KeyManager::UnSetKey(u_int16_t lid, IBISKeyType key_type)
{
    IBIS_ENTER;

    if (KeyManager::IsVlaidKeyType(key_type))
        this->lid_2_key_vec_vec[key_type][lid].is_set = false;

    IBIS_RETURN_VOID;
}
